--[[
-- Prankstars Elegant UI - Namespaces and variables
]]--
local PrankUI = "PrankUI";
local PrankUIReload = "PrankUI.reload";
local ProfileName = "PrankUI";
local MediaPath = "interface/addons/PrankUI_Setup/media/";
local FrameStrata = "HIGH"; -- BACKGROUND, LOW, MEDIUM, HIGH, DIALOG, FULLSCREEN, FULLSCREEN_DIALOG, TOOLTIP




--[[
    Setup window
]]--

-- Main frame
PrankstarsElegantUI = CreateFrame("Frame", PrankUI, UIParent);
local UISetup = PrankstarsElegantUI;
UISetup:SetFrameStrata(FrameStrata);
UISetup:SetSize(1024, 256); -- W, H
UISetup:SetPoint("CENTER", UIParent, "CENTER", 0, 128); -- point, relative frame, relative point, x, y
UISetup:SetFrameLevel(1);
UISetup.bg = UISetup:CreateTexture(PrankUI..".bg", "BACKGROUND");
UISetup.bg:SetAllPoints();
UISetup.bg:SetTexture(MediaPath.."background.tga");

-- Option
UISetup.option = CreateFrame("Frame", PrankUI..".option", UISetup);
UISetup.option:SetSize(512, 128);
UISetup.option:SetPoint("BOTTOM", UISetup, "BOTTOM", 0, -32);
UISetup.option:SetFrameLevel(3);
UISetup.option.bg = UISetup.option:CreateTexture(PrankUI..".option.bg", "BACKGROUND");
UISetup.option.bg:SetAllPoints();
UISetup.option.bg:SetTexture(MediaPath.."option.blp");

-- Default
UISetup.defaultHover = CreateFrame("Frame", PrankUI..".defaultHover", UISetup);
UISetup.defaultHover:SetSize(512, 128);
UISetup.defaultHover:SetPoint("RIGHT", UISetup.option, "CENTER", 20, 27);
UISetup.defaultHover:SetFrameLevel(2);
UISetup.defaultHover:SetAlpha(0);
UISetup.defaultHover.bg = UISetup.defaultHover:CreateTexture(PrankUI..".defaultHover.bg", "BACKGROUND");
UISetup.defaultHover.bg:SetAllPoints();
UISetup.defaultHover.bg:SetTexture(MediaPath.."option-left-hover.blp");
UISetup.defaultButton = CreateFrame("Button", PrankUI..".defaultButton", UISetup);
UISetup.defaultButton:SetSize(232, 70);
UISetup.defaultButton:SetPoint("RIGHT", UISetup.option, "CENTER", 0, 30);

-- Darkened
UISetup.darkenedHover = CreateFrame("Frame", PrankUI..".darkenedHover", UISetup);
UISetup.darkenedHover:SetSize(512, 128);
UISetup.darkenedHover:SetPoint("LEFT", UISetup.option, "CENTER", -20, 27);
UISetup.darkenedHover:SetFrameLevel(2);
UISetup.darkenedHover:SetAlpha(0);
UISetup.darkenedHover.bg = UISetup.darkenedHover:CreateTexture(PrankUI..".darkenedHover.bg", "BACKGROUND");
UISetup.darkenedHover.bg:SetAllPoints();
UISetup.darkenedHover.bg:SetTexture(MediaPath.."option-right-hover.blp");
UISetup.darkenedButton = CreateFrame("Button", PrankUI..".darkenedButton", UISetup);
UISetup.darkenedButton:SetSize(232, 70);
UISetup.darkenedButton:SetPoint("LEFT", UISetup.option, "CENTER", 0, 30);

-- Hide main frame
UISetup:Hide();




--[[
    Reload window
]]--

-- Main frame
local UIReload = CreateFrame("Frame", PrankUIReload, UIParent);
UIReload:SetFrameStrata(FrameStrata);
UIReload:SetSize(1024, 256); -- W, H
UIReload:SetPoint("CENTER", UIParent, "CENTER", 0, 128); -- point, relative frame, relative point, x, y
UIReload:SetFrameLevel(5);
UIReload.bgInit = UIReload:CreateTexture(PrankUIReload..".bg", "BACKGROUND");
UIReload.bgInit:SetAllPoints();
UIReload.bgInit:SetTexture(MediaPath.."reload.tga");
UIReload.bgHover = UIReload:CreateTexture(PrankUIReload..".bg", "BACKGROUND");
UIReload.bgHover:SetAllPoints();
UIReload.bgHover:SetTexture(MediaPath.."reload-hover.tga");
UIReload.bgHover:SetAlpha(0);

-- Reload
UIReload.button = CreateFrame("Button", PrankUIReload..".button", UIReload);
UIReload.button:SetSize(54, 54);
UIReload.button:SetPoint("BOTTOM", UIReload, "BOTTOM", 0, 35);
UIReload.button:SetFrameLevel(6);
UIReload.button:SetAlpha(0);

-- Hide main frame
UIReload:Hide();




--[[
    Profiles
]]--
local PrankUISetup = {};

local DominosDB = LibStub("AceAddon-3.0"):GetAddon("Dominos");
local CastbarsDB = LibStub("AceAddon-3.0"):GetAddon("Castbars");
local MasqueDB = LibStub("AceAddon-3.0"):GetAddon("Masque");
local kgPanelsDB = LibStub("AceAddon-3.0"):GetAddon("kgPanels");
local ChatterDB = LibStub("AceAddon-3.0"):GetAddon("Chatter");

PrankUISetup.DB = function(addon, addonLayout)
    addon:SetProfile(UnitName("player").." - "..GetRealmName());

    if addonLayout == "default" then
        addon:CopyProfile(ProfileName.."-default", true);
    elseif addonLayout == "darkened" then
        addon:CopyProfile(ProfileName.."-darkened", true);
    else
        addon:CopyProfile(ProfileName, true);
    end
end

PrankUISetup.Setup = function(layout)
    -- Settings
    SetCVar("scriptErrors", 1);
    SetCVar("nameplateShowAll", 1);
    SetCVar("nameplateShowEnemies", 1);
    SetCVar("nameplateShowEnemyMinus", 1);
    SetCVar("nameplateShowEnemyTotems", 1);
    SetCVar("nameplateShowEnemyGuardians", 1);
    SetCVar("nameplateShowEnemyPets", 1);
    SetCVar("nameplateShowEnemyMinions", 1);
    SetCVar("nameplateShowSelf", 0);
    SetCVar("nameplateMaxDistance", 40);
    SetCVar("countdownForCooldowns", 0);
    SetCVar("mapFade", 0);
    SetCVar("useUiScale", 0);
    SetActionBarToggles(1, 1, 1, 1);

    -- Profiles
    SexyMap2DB[(UnitName("player").."-"..GetRealmName())] = "global";
    PrankUISetup.DB(ShadowUF.db);
    PrankUISetup.DB(Skada.db);
    PrankUISetup.DB(ChatterDB.db);
    PrankUISetup.DB(DominosDB.db);
    PrankUISetup.DB(MasqueDB, layout);
    PrankUISetup.DB(CastbarsDB.db, layout);
    PrankUISetup.DB(kgPanelsDB.db, layout);

    -- Change window
    UIReload:Show();
    UISetup:Hide();
    -- print("Reload UI to finalize setup. Click the circle button or type '/reload'");
end




--[[
    Mouse events
]]--

-- Default
UISetup.defaultButton:SetScript("OnEnter", function()
    UISetup.defaultHover:SetAlpha(1);
end);
UISetup.defaultButton:SetScript("OnLeave", function()
    UISetup.defaultHover:SetAlpha(0);
end);
UISetup.defaultButton:SetScript("OnClick", function()
    -- print("Default layout selected");
    PrankUISetup.Setup("default");
end);

-- Darkened
UISetup.darkenedButton:SetScript("OnEnter", function()
    UISetup.darkenedHover:SetAlpha(1);
end);
UISetup.darkenedButton:SetScript("OnLeave", function()
    UISetup.darkenedHover:SetAlpha(0);
end);
UISetup.darkenedButton:SetScript("OnClick", function()
    -- print("Darkened layout selected");
    PrankUISetup.Setup("darkened");
end);

-- Reload
UIReload.button:SetScript("OnEnter", function()
    UIReload.bgInit:SetAlpha(0);
    UIReload.bgHover:SetAlpha(1);
end);
UIReload.button:SetScript("OnLeave", function()
    UIReload.bgInit:SetAlpha(1);
    UIReload.bgHover:SetAlpha(0);
end);
UIReload.button:SetScript("OnClick", function()
    ReloadUI();
end);







--[[
    Slash Command
]]--

-- Open setup window
SLASH_PRANKUI1 = "/prankui"

SlashCmdList["PRANKUI"] = function(msg)
    if UISetup:IsShown() then
        UISetup:Hide();
    else
        UISetup:Show();
    end
end
